DiagnosticCode

Enum DiagnosticCode 

#[non_exhaustive]
pub enum DiagnosticCode {
Show 22 variants UnsupportedArrowType, LossyConversionRequiresPolicy, PolicyApplied, IdentifierInvalid, IdentifierTooLong, DecimalOutOfRange, IntegerOutOfRange, TimestampOutOfRange, TimezoneUnsupported, SchemaMismatch, BackendUnavailable, ProfileDependentConversion, ObservedDataRequired, ValueConversionUnsupported, ValueTypeMismatch, NullInNonNullableColumn, NonFiniteFloat, ValueTooLong, RowIndexOutOfBounds, DirectEncodingInvalidPayload, DirectEncodingUnsupportedMapping, DirectEncodingUnsupportedBatch,
}
Machine-readable diagnostic code.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnsupportedArrowType

An Arrow type is not supported by the selected operation.



LossyConversionRequiresPolicy

A conversion may lose information and requires explicit policy.



PolicyApplied

An explicit conversion policy was applied.



IdentifierInvalid

A SQL Server identifier is invalid.



IdentifierTooLong

A SQL Server identifier exceeds the supported length.



DecimalOutOfRange

A decimal value, precision, or scale is outside the supported range.



IntegerOutOfRange

An integer value is outside the supported range.



TimestampOutOfRange

A timestamp value is outside the supported range.



TimezoneUnsupported

A timestamp timezone cannot be mapped to a deterministic SQL Server value.

This is used for invalid timezone names, invalid fixed offset strings, and resolved offsets SQL Server cannot represent.



SchemaMismatch

A runtime batch schema does not match the planned schema.



BackendUnavailable

A requested write backend is unavailable.



ProfileDependentConversion

A mapping depends on explicit user policy.



ObservedDataRequired

A selected policy needs observed values or statistics, not just schema.



ValueConversionUnsupported

A planned value conversion is not supported by the current converter.



ValueTypeMismatch

A runtime value or array type does not match the planned conversion.



NullInNonNullableColumn

A runtime null value was found for a non-nullable target column.



NonFiniteFloat

A floating-point value is not finite.



ValueTooLong

A runtime value exceeds the planned target type length.



RowIndexOutOfBounds

A requested row index is outside the runtime batch.



DirectEncodingInvalidPayload

Direct raw TDS encoding produced or received invalid payload state.



DirectEncodingUnsupportedMapping

A planned mapping is not supported by the direct raw TDS encoder.



DirectEncodingUnsupportedBatch

Runtime batch shape is not supported by the current direct raw TDS encoder.