Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 17 variants WritePhaseContext { phase: WritePhase, source: Box<Error>, }, InvalidCompatibilityLevel { level: u16, }, UnsupportedCompatibilityLevel { version: MssqlVersion, compatibility_level: u16, }, InvalidIdentifier { reason: String, }, Planning { diagnostics: DiagnosticSet, }, ValueConversion { diagnostics: DiagnosticSet, }, DirectEncoding { diagnostics: DiagnosticSet, }, BackendUnavailable { backend: WriteBackend, reason: String, }, InvalidConnectionString, ConnectionTcpConnect { source: Error, }, ConnectionClientSetup { source: Error, }, TableExistsQuery { source: Error, }, TableExistsUnexpectedResult { reason: String, }, TargetRowCountQuery { source: Error, }, TargetRowCountUnexpectedResult { reason: String, }, SqlExecution { source: Error, }, Tiberius { source: Error, },
}
Error type for arrow-tiberius operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


WritePhaseContext

A write-path operation failed in a known writer phase.

Fields

phase: WritePhase

Stable writer phase where the failure was observed.

source: Box<Error>

Original error raised by the failing operation.



InvalidCompatibilityLevel

A SQL Server database compatibility level is not supported.

Fields

level: u16

The unsupported compatibility level value.



UnsupportedCompatibilityLevel

A SQL Server database compatibility level is not supported by the selected SQL Server engine version.

Fields

version: MssqlVersion

SQL Server engine version.

compatibility_level: u16

Unsupported compatibility level value for the selected version.



InvalidIdentifier

A SQL Server identifier is invalid for the selected identifier policy.

Fields

reason: String

Human-readable reason the identifier is invalid.



Planning

Arrow schema planning failed.

Fields

diagnostics: DiagnosticSet

Structured planning diagnostics.



ValueConversion

Runtime value conversion failed.

Fields

diagnostics: DiagnosticSet

Structured value conversion diagnostics.



DirectEncoding

Direct raw TDS encoding failed.

Fields

diagnostics: DiagnosticSet

Structured direct encoding diagnostics.



BackendUnavailable

A requested write backend is not available.

Fields

backend: WriteBackend

Requested write backend.

reason: String

Human-readable reason the backend is unavailable.



InvalidConnectionString

A SQL Server ADO-style connection string is invalid.



ConnectionTcpConnect

Opening the TCP connection to SQL Server failed.

Fields

source: Error

Source I/O error returned by the TCP transport.



ConnectionClientSetup

Tiberius failed while establishing the SQL Server client session.

Fields

source: Error

Source error returned by Tiberius.



TableExistsQuery

SQL Server table-existence metadata query failed.

Fields

source: Error

Source error returned by Tiberius.



TableExistsUnexpectedResult

SQL Server table-existence metadata query returned an unexpected shape.

Fields

reason: String

Human-readable reason the metadata result could not be interpreted.



TargetRowCountQuery

SQL Server target row-count query failed.

Fields

source: Error

Source error returned by Tiberius.



TargetRowCountUnexpectedResult

SQL Server target row-count query returned an unexpected shape.

Fields

reason: String

Human-readable reason the target row-count result could not be interpreted.



SqlExecution

SQL Server lifecycle statement execution failed.

Fields

source: Error

Source error returned by Tiberius.



Tiberius

Tiberius returned an error while executing a SQL Server operation.

Fields

source: Error

Source error returned by Tiberius.

Implementations

Source

impl Error

pub fn with_write_phase(self, phase: WritePhase) -> Self

Attaches stable writer phase context to an error.

pub const fn write_phase(&self) -> Option<WritePhase>

Returns the stable writer phase when the error can be classified.

pub fn without_write_phase(&self) -> &Self

Returns the inner error without writer phase context.

pub fn safe_error_info(&self) -> ErrorInfo<'_>

Returns safe, structured information for user-facing reports.