DirectWriteProfile

Struct DirectWriteProfile 

pub struct DirectWriteProfile {
Show 80 fields pub measure_batch: Duration, pub row_range_split: Duration, pub append_encode: Duration, pub send_total: Duration, pub rows: u64, pub batches: u64, pub row_ranges: u64, pub encoded_bytes: u64, pub max_row_range_bytes: u64, pub nvarchar_utf16_bytes: u64, pub varbinary_bytes: u64, pub null_cells: u64, pub packet_write_calls: u64, pub packets_written: u64, pub packet_payload_bytes: u64, pub max_packet_payload_bytes: u64, pub max_buffered_bytes_before_write: u64, pub buffered_bytes_after_last_write: u64, pub finalized_packet_payload_bytes: u64, pub bulk_write_packets_elapsed: Duration, pub bulk_write_to_wire_calls: u64, pub bulk_write_to_wire_elapsed: Duration, pub bulk_write_to_wire_payload_bytes: u64, pub bulk_max_write_to_wire_elapsed: Duration, pub bulk_max_write_to_wire_payload_bytes: u64, pub bulk_flush_calls: u64, pub bulk_flush_elapsed: Duration, pub bulk_max_flush_elapsed: Duration, pub bulk_finalize_elapsed: Duration, pub bulk_finalize_write_to_wire_elapsed: Duration, pub bulk_finalize_flush_elapsed: Duration, pub bulk_finalize_result_elapsed: Duration, pub bulk_connection_write_calls: u64, pub bulk_connection_write_payload_bytes: u64, pub bulk_connection_write_ready_elapsed: Duration, pub bulk_connection_write_encode_elapsed: Duration, pub bulk_connection_write_flush_elapsed: Duration, pub bulk_connection_write_max_ready_elapsed: Duration, pub bulk_connection_write_max_encode_elapsed: Duration, pub bulk_connection_write_max_flush_elapsed: Duration, pub bulk_connection_write_max_payload_bytes: u64, pub bulk_direct_packet_write_calls: u64, pub bulk_direct_packet_payload_bytes: u64, pub bulk_direct_packet_header_bytes: u64, pub bulk_direct_packet_max_payload_bytes: u64, pub bulk_direct_packet_final_calls: u64, pub bulk_direct_packet_final_payload_bytes: u64, pub bulk_direct_packet_final_header_bytes: u64, pub bulk_direct_packet_raw_stream_calls: u64, pub bulk_direct_packet_tls_stream_calls: u64, pub bulk_direct_packet_low_level_write_calls: u64, pub bulk_direct_packet_low_level_write_bytes: u64, pub bulk_direct_packet_max_low_level_write_bytes: u64, pub bulk_direct_packet_write_elapsed: Duration, pub bulk_direct_packet_max_write_elapsed: Duration, pub bulk_direct_packet_header_write_calls: u64, pub bulk_direct_packet_header_write_bytes: u64, pub bulk_direct_packet_header_max_write_bytes: u64, pub bulk_direct_packet_header_write_elapsed: Duration, pub bulk_direct_packet_header_max_write_elapsed: Duration, pub bulk_direct_packet_header_partial_writes: u64, pub bulk_direct_packet_payload_write_calls: u64, pub bulk_direct_packet_payload_write_bytes: u64, pub bulk_direct_packet_payload_max_write_bytes: u64, pub bulk_direct_packet_payload_write_elapsed: Duration, pub bulk_direct_packet_payload_max_write_elapsed: Duration, pub bulk_direct_packet_payload_partial_writes: u64, pub bulk_direct_packet_poll_write_polls: u64, pub bulk_direct_packet_poll_write_pending_count: u64, pub bulk_direct_packet_poll_write_pending_elapsed: Duration, pub bulk_direct_packet_poll_write_max_pending_elapsed: Duration, pub bulk_direct_packet_poll_write_ready_count: u64, pub bulk_direct_packet_poll_write_ready_elapsed: Duration, pub bulk_direct_packet_poll_write_max_ready_elapsed: Duration, pub bulk_direct_packet_flush_calls: u64, pub bulk_direct_packet_flush_elapsed: Duration, pub bulk_direct_packet_max_flush_elapsed: Duration, pub bulk_direct_packet_flush_pending_count: u64, pub bulk_direct_packet_flush_pending_elapsed: Duration, pub bulk_direct_packet_flush_max_pending_elapsed: Duration,
}
Accumulated timings for the direct raw writer path.

Fields

measure_batch: Duration

Time spent measuring runtime batches before encoding.

row_range_split: Duration

Time spent splitting measured batches into bounded row ranges.

append_encode: Duration

Time spent encoding/appending raw rows before Tiberius writes packets.

send_total: Duration

Total time spent in raw-row send calls, including append encoding.

rows: u64

Number of rows accepted by the direct writer.

batches: u64

Number of batches accepted by the direct writer.

row_ranges: u64

Number of raw row ranges sent.

encoded_bytes: u64

Total encoded raw row bytes sent or appended.

max_row_range_bytes: u64

Largest encoded row range in bytes.

nvarchar_utf16_bytes: u64

Non-null SQL Server nvarchar payload bytes after UTF-16 encoding.

varbinary_bytes: u64

Non-null SQL Server varbinary payload bytes.

null_cells: u64

Number of null cells observed by the profiled direct writer path.

packet_write_calls: u64

Number of bulk packet drain attempts inside Tiberius.

packets_written: u64

Number of full TDS bulk-load packets written before finalization.

packet_payload_bytes: u64

Total packet payload bytes written before finalization.

max_packet_payload_bytes: u64

Largest full packet payload written before finalization.

max_buffered_bytes_before_write: u64

Largest buffered bulk-load byte count before a packet drain attempt.

buffered_bytes_after_last_write: u64

Buffered bulk-load tail left after the latest packet drain attempt.

finalized_packet_payload_bytes: u64

Final EndOfMessage packet payload bytes written during finalization.

bulk_write_packets_elapsed: Duration

Time spent inside bulk-load packet drain attempts.

bulk_write_to_wire_calls: u64

Number of lower-level connection writes issued by bulk load.

bulk_write_to_wire_elapsed: Duration

Time spent awaiting lower-level connection writes from bulk load.

bulk_write_to_wire_payload_bytes: u64

Payload bytes passed to lower-level connection writes from bulk load.

bulk_max_write_to_wire_elapsed: Duration

Slowest lower-level connection write awaited by bulk load.

bulk_max_write_to_wire_payload_bytes: u64

Largest lower-level connection write payload from bulk load.

bulk_flush_calls: u64

Number of explicit bulk-load flushes.

bulk_flush_elapsed: Duration

Time spent awaiting explicit bulk-load flushes.

bulk_max_flush_elapsed: Duration

Slowest explicit bulk-load flush.

bulk_finalize_elapsed: Duration

Time spent finalizing the bulk-load request.

bulk_finalize_write_to_wire_elapsed: Duration

Time spent awaiting the final EndOfMessage packet write.

bulk_finalize_flush_elapsed: Duration

Time spent awaiting the final explicit flush.

bulk_finalize_result_elapsed: Duration

Time spent waiting for the server result after final bulk flush.

bulk_connection_write_calls: u64

Number of bulk-load packets passed through the framed connection sink.

bulk_connection_write_payload_bytes: u64

Payload bytes passed through the framed connection sink.

bulk_connection_write_ready_elapsed: Duration

Time spent waiting for the framed connection sink to accept packets.

bulk_connection_write_encode_elapsed: Duration

Time spent encoding packets into the framed connection sink.

bulk_connection_write_flush_elapsed: Duration

Time spent flushing packets through the framed connection sink.

bulk_connection_write_max_ready_elapsed: Duration

Slowest framed connection sink readiness wait.

bulk_connection_write_max_encode_elapsed: Duration

Slowest packet encode into the framed connection sink.

bulk_connection_write_max_flush_elapsed: Duration

Slowest framed connection sink flush.

bulk_connection_write_max_payload_bytes: u64

Largest payload passed through the framed connection sink.

bulk_direct_packet_write_calls: u64

Number of bulk-load packets written through the direct packet path.

bulk_direct_packet_payload_bytes: u64

Payload bytes written through the direct packet path.

bulk_direct_packet_header_bytes: u64

Header bytes written through the direct packet path.

bulk_direct_packet_max_payload_bytes: u64

Largest packet payload written through the direct packet path.

bulk_direct_packet_final_calls: u64

Number of final EndOfMessage direct packets.

bulk_direct_packet_final_payload_bytes: u64

Payload bytes in final EndOfMessage direct packets.

bulk_direct_packet_final_header_bytes: u64

Header bytes in final EndOfMessage direct packets.

bulk_direct_packet_raw_stream_calls: u64

Direct packet writes observed on raw, non-TLS streams.

bulk_direct_packet_tls_stream_calls: u64

Direct packet writes observed on TLS streams.

bulk_direct_packet_low_level_write_calls: u64

Low-level write calls issued by the direct packet path.

bulk_direct_packet_low_level_write_bytes: u64

Low-level bytes written by the direct packet path.

bulk_direct_packet_max_low_level_write_bytes: u64

Largest low-level write accepted by the direct packet path.

bulk_direct_packet_write_elapsed: Duration

Time spent in low-level writes for the direct packet path.

bulk_direct_packet_max_write_elapsed: Duration

Slowest low-level write in the direct packet path.

bulk_direct_packet_header_write_calls: u64

Low-level write calls used for direct packet headers.

bulk_direct_packet_header_write_bytes: u64

Header bytes accepted by low-level writes.

bulk_direct_packet_header_max_write_bytes: u64

Largest header byte count accepted by one low-level write.

bulk_direct_packet_header_write_elapsed: Duration

Time spent in low-level header writes.

bulk_direct_packet_header_max_write_elapsed: Duration

Slowest low-level header write.

bulk_direct_packet_header_partial_writes: u64

Low-level header writes that accepted fewer bytes than remained.

bulk_direct_packet_payload_write_calls: u64

Low-level write calls used for direct packet payloads.

bulk_direct_packet_payload_write_bytes: u64

Payload bytes accepted by low-level writes.

bulk_direct_packet_payload_max_write_bytes: u64

Largest payload byte count accepted by one low-level write.

bulk_direct_packet_payload_write_elapsed: Duration

Time spent in low-level payload writes.

bulk_direct_packet_payload_max_write_elapsed: Duration

Slowest low-level payload write.

bulk_direct_packet_payload_partial_writes: u64

Low-level payload writes that accepted fewer bytes than remained.

bulk_direct_packet_poll_write_polls: u64

Number of low-level poll_write attempts.

bulk_direct_packet_poll_write_pending_count: u64

Number of low-level poll_write attempts that returned Pending.

bulk_direct_packet_poll_write_pending_elapsed: Duration

Time spent waiting after low-level poll_write returned Pending.

bulk_direct_packet_poll_write_max_pending_elapsed: Duration

Slowest wait after low-level poll_write returned Pending.

bulk_direct_packet_poll_write_ready_count: u64

Number of low-level poll_write attempts that returned ready.

bulk_direct_packet_poll_write_ready_elapsed: Duration

Time spent in ready low-level poll_write attempts.

bulk_direct_packet_poll_write_max_ready_elapsed: Duration

Slowest ready low-level poll_write attempt.

bulk_direct_packet_flush_calls: u64

Explicit flush calls issued by the direct packet path.

bulk_direct_packet_flush_elapsed: Duration

Time spent flushing the direct packet path.

bulk_direct_packet_max_flush_elapsed: Duration

Slowest flush in the direct packet path.

bulk_direct_packet_flush_pending_count: u64

Number of direct packet flush polls that returned Pending.

bulk_direct_packet_flush_pending_elapsed: Duration

Time spent waiting after direct packet flush polls returned Pending.

bulk_direct_packet_flush_max_pending_elapsed: Duration

Slowest wait after a direct packet flush poll returned Pending.

Implementations

Source

impl DirectWriteProfile

pub fn send_without_append_encode(&self) -> Duration

Returns approximate send time outside the append/encode closure.