#[non_exhaustive]pub enum Error {
Show 17 variants
WritePhaseContext {
phase: WritePhase,
source: Box<Error>,
},
InvalidCompatibilityLevel {
level: u16,
},
UnsupportedCompatibilityLevel {
version: MssqlVersion,
compatibility_level: u16,
},
InvalidIdentifier {
reason: String,
},
Planning {
diagnostics: DiagnosticSet,
},
ValueConversion {
diagnostics: DiagnosticSet,
},
DirectEncoding {
diagnostics: DiagnosticSet,
},
BackendUnavailable {
backend: WriteBackend,
reason: String,
},
InvalidConnectionString,
ConnectionTcpConnect {
source: Error,
},
ConnectionClientSetup {
source: Error,
},
TableExistsQuery {
source: Error,
},
TableExistsUnexpectedResult {
reason: String,
},
TargetRowCountQuery {
source: Error,
},
TargetRowCountUnexpectedResult {
reason: String,
},
SqlExecution {
source: Error,
},
Tiberius {
source: Error,
},
}Expand description
Error type for arrow-tiberius operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
WritePhaseContext
A write-path operation failed in a known writer phase.
Fields
phase: WritePhaseStable writer phase where the failure was observed.
InvalidCompatibilityLevel
A SQL Server database compatibility level is not supported.
UnsupportedCompatibilityLevel
A SQL Server database compatibility level is not supported by the selected SQL Server engine version.
Fields
version: MssqlVersionSQL Server engine version.
InvalidIdentifier
A SQL Server identifier is invalid for the selected identifier policy.
Planning
Arrow schema planning failed.
Fields
diagnostics: DiagnosticSetStructured planning diagnostics.
ValueConversion
Runtime value conversion failed.
Fields
diagnostics: DiagnosticSetStructured value conversion diagnostics.
DirectEncoding
Direct raw TDS encoding failed.
Fields
diagnostics: DiagnosticSetStructured direct encoding diagnostics.
A requested write backend is not available.
InvalidConnectionString
A SQL Server ADO-style connection string is invalid.
ConnectionTcpConnect
Opening the TCP connection to SQL Server failed.
ConnectionClientSetup
Tiberius failed while establishing the SQL Server client session.
TableExistsQuery
SQL Server table-existence metadata query failed.
TableExistsUnexpectedResult
SQL Server table-existence metadata query returned an unexpected shape.
TargetRowCountQuery
SQL Server target row-count query failed.
TargetRowCountUnexpectedResult
SQL Server target row-count query returned an unexpected shape.
SqlExecution
SQL Server lifecycle statement execution failed.
Tiberius
Tiberius returned an error while executing a SQL Server operation.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn with_write_phase(self, phase: WritePhase) -> Self
pub fn with_write_phase(self, phase: WritePhase) -> Self
Attaches stable writer phase context to an error.
Sourcepub const fn write_phase(&self) -> Option<WritePhase>
pub const fn write_phase(&self) -> Option<WritePhase>
Returns the stable writer phase when the error can be classified.
Sourcepub fn without_write_phase(&self) -> &Self
pub fn without_write_phase(&self) -> &Self
Returns the inner error without writer phase context.
Sourcepub fn safe_error_info(&self) -> ErrorInfo<'_>
pub fn safe_error_info(&self) -> ErrorInfo<'_>
Returns safe, structured information for user-facing reports.